#! /bin/csh
#
# Name: update_opus_load_date_a.s
#
# Description:
#
# Called by:   update_opus_load_date.s
#
# Requires:    env var CDBS_EMAIL_DISTRIB
#              env var CDBS_SERVER
#              env var CDBS_DB
#
#---------------------------------------------------------------------------
setenv addr "${CDBS_EMAIL_DISTRIB}"
echo "-----------------"
date

# verify the DB env vars are defined
if ( ${?CDBS_DB} == 0 ) then
    mail -s "Environment variable CDBS_DB undefined" $addr < $file
    echo "Environment variable CDBS_DB undefined"
    #mv -f $file $OPUS_OUTPUT_DIR/trouble
    exit
endif

if ( ${?CDBS_SERVER} == 0 ) then
    mail -s "Environment variable CDBS_SERVER undefined" $addr < $file
    echo "Environment variable CDBS_SERVER undefined"
    #mv -f $file $OPUS_OUTPUT_DIR/trouble
    exit
endif

# Look at each delivered file from OPUS
foreach file ($OPUS_OUTPUT_DIR/*.sqlout)

  # Check on whether the file was free of errors and send email.
  set w = `grep OPUS_MODS_OK $file | wc -l`
  if ($w == 0) then
     mail -s "Failed OPUS SQL for file $file" $addr < $file
     echo "Failed OPUS SQL: see trouble$file"
     \mv -f $file $OPUS_OUTPUT_DIR/trouble
     # If there are errors, then quit.
     goto jump
  endif

  mail -s "OPUS MODS OK $file" $addr < $file
  echo "OPUS MODS OK $file"

  # Determine the opus_load_date and delivery_number for cdbs
  set awk_source_file = `which opus_load_date_awk.ld`
  set load_date = `awk -f ${awk_source_file} $file`
  echo "load_date=" $load_date

  if ( `echo $load_date | wc -l` == 0) then
    mail -s "Empty load_date $file" $addr < $file
    echo "Empty load_date $file"
    \mv -f $file $OPUS_OUTPUT_DIR/trouble
    goto jump
  endif

  set awk_source_file = `which opus_load_date_awk.dn`
  set delivery_number = `awk -f $awk_source_file $file `
  echo "delivery_number=" $delivery_number
  if ( `echo $delivery_number | wc -l` == 0) then
    mail -s "Empty delivery_number $file" $addr < $file
    echo "Empty delivery_number $file"
    \mv -f $file $OPUS_OUTPUT_DIR/trouble
    goto jump
  endif

  # Update the opus_load_date for this delivery
  opus_load_date_load_date.s $CDBS_DB $delivery_number "$load_date" > $OPUS_OUTPUT_DIR/load_date_$delivery_number.output
  chmod 660 $OPUS_OUTPUT_DIR/load_date_$delivery_number.output

  # Determine whether the update succeeded, send email, and move files to
  # the done directory.
  set w = `grep 'IS OK' $OPUS_OUTPUT_DIR/load_date_$delivery_number.output | wc -l`
  if ($w == 0) then
     mail -s "Failed CDBS update of opus_load_date for delivery number $delivery_number" $addr  < $OPUS_OUTPUT_DIR/load_date_$delivery_number.output
     echo "Failed CDBS update of opus_load_date for delivery number $delivery_number"
     \mv -f $OPUS_OUTPUT_DIR/load_date_$delivery_number.output $OPUS_OUTPUT_DIR/trouble
     \mv -f $file $OPUS_OUTPUT_DIR/trouble
     goto jump
  endif

  mail -s "CDBS update of opus_load_date OK for delivery number $delivery_number" $addr < $OPUS_OUTPUT_DIR/load_date_$delivery_number.output
  echo "CDBS update of opus_load_date OK for delivery number $delivery_number"
  \mv -f $OPUS_OUTPUT_DIR/load_date_$delivery_number.output $OPUS_OUTPUT_DIR/done
  \mv -f $file $OPUS_OUTPUT_DIR/done

#end of foreach loop,done
jump:
end
